# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .get_sentry_dashboard import *
from .get_sentry_issue_alert import *
from .get_sentry_key import *
from .get_sentry_metric_alert import *
from .get_sentry_organization import *
from .get_sentry_organization_integration import *
from .get_sentry_team import *
from .provider import *
from .sentry_dashboard import *
from .sentry_issue_alert import *
from .sentry_key import *
from .sentry_metric_alert import *
from .sentry_organization import *
from .sentry_organization_code_mapping import *
from .sentry_organization_member import *
from .sentry_organization_repository_github import *
from .sentry_plugin import *
from .sentry_project import *
from .sentry_rule import *
from .sentry_team import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_sentry.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_sentry.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "sentry",
  "mod": "index/sentryDashboard",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryDashboard:SentryDashboard": "SentryDashboard"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryIssueAlert",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryIssueAlert:SentryIssueAlert": "SentryIssueAlert"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryKey",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryKey:SentryKey": "SentryKey"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryMetricAlert",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryMetricAlert:SentryMetricAlert": "SentryMetricAlert"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganization",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganization:SentryOrganization": "SentryOrganization"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationCodeMapping",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationCodeMapping:SentryOrganizationCodeMapping": "SentryOrganizationCodeMapping"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationMember",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationMember:SentryOrganizationMember": "SentryOrganizationMember"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryOrganizationRepositoryGithub",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryOrganizationRepositoryGithub:SentryOrganizationRepositoryGithub": "SentryOrganizationRepositoryGithub"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryPlugin",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryPlugin:SentryPlugin": "SentryPlugin"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryProject",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryProject:SentryProject": "SentryProject"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryRule",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryRule:SentryRule": "SentryRule"
  }
 },
 {
  "pkg": "sentry",
  "mod": "index/sentryTeam",
  "fqn": "pulumiverse_sentry",
  "classes": {
   "sentry:index/sentryTeam:SentryTeam": "SentryTeam"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "sentry",
  "token": "pulumi:providers:sentry",
  "fqn": "pulumiverse_sentry",
  "class": "Provider"
 }
]
"""
)
